@@ -1,14 +1,15 @@
 package File::Temp::MoreUtils;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-12'; # DATE
+our $DATE = '2021-07-13'; # DATE
 our $DIST = 'File-Temp-MoreUtils'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001; # for // & state var
 use strict;
 use warnings;
 
+use Errno 'EEXIST';
 use Fcntl ':DEFAULT';
 use File::Temp ();
 
@@ -122,7 +123,7 @@ sub tempfile_named {
         if (sysopen $fh, $name, O_CREAT | O_CREAT | O_EXCL) {
             return ($fh, $name);
         }
-        unless ($! =~ /File exists/) {
+        unless ($! == EEXIST) {
             die "tempfile_named(): Can't create temporary file '$name': $!";
         }
         if ($counter++ > 10_000) {
@@ -146,7 +147,7 @@ File::Temp::MoreUtils - Provide more routines related to creating temporary file
 
 =head1 VERSION
 
-This document describes version 0.002 of File::Temp::MoreUtils (from Perl distribution File-Temp-MoreUtils), released on 2021-07-12.
+This document describes version 0.003 of File::Temp::MoreUtils (from Perl distribution File-Temp-MoreUtils), released on 2021-07-13.
 
 =head1 SYNOPSIS
 
